==> openGion_dev_5.9.17.1.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF03S.sql <==
/****************************************************************************/
/* GF03 ( ﾃｰﾌﾞﾙｶﾗﾑ定義ﾏｽﾀ )                                                 */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF03 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , NAME_JA          varchar           (  200 )                                      /*  30 名称         */
 , CLS_NAME         varchar           (   10 )                  NOT NULL            /*  40 DBｸﾗｽ        */
 , USE_LENGTH       varchar           (    9 )      DEFAULT 0                       /*  50 使用桁数     */
 , DATA_DEFAULT     varchar           (  200 )                                      /*  60 初期値       */
 , FGIMP            varchar           (    1 )      DEFAULT 0   NOT NULL            /*  70 重要度       */
 , RENDERER         varchar           (   10 )                                      /*  80 表示種別     */
 , EDITOR           varchar           (   10 )                                      /*  90 編集種別     */
 , DBTYPE           varchar           (   10 )                                      /* 100 文字種別     */
 , RENDERER_PARAM   varchar           (  200 )                                      /* 110 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     varchar           (  200 )                                      /* 120 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       varchar           (  200 )                                      /* 130 文字ﾊﾟﾗﾒｰﾀ   */
 , BIKO             varchar           ( 2000 )                                      /* 140 備考         */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /* 150 表示順       */
 , CDKH             varchar           (    1 )                                      /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF03S.sql <==
/****************************************************************************/
/* GF03 ( ﾃｰﾌﾞﾙｶﾗﾑ定義ﾏｽﾀ )                                                 */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF03 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , NAME_JA          varchar           (  200 )                                      /*  30 名称         */
 , CLS_NAME         varchar           (   10 )                  NOT NULL            /*  40 DBｸﾗｽ        */
 , USE_LENGTH       varchar           (    9 )      DEFAULT '0'                     /*  50 使用桁数     */
 , DATA_DEFAULT     varchar           (  200 )                                      /*  60 初期値       */
 , FGIMP            varchar           (    1 )      DEFAULT '0' NOT NULL            /*  70 重要度       */
 , RENDERER         varchar           (   10 )                                      /*  80 表示種別     */
 , EDITOR           varchar           (   10 )                                      /*  90 編集種別     */
 , DBTYPE           varchar           (   10 )                                      /* 100 文字種別     */
 , RENDERER_PARAM   varchar           (  200 )                                      /* 110 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     varchar           (  200 )                                      /* 120 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       varchar           (  200 )                                      /* 130 文字ﾊﾟﾗﾒｰﾀ   */
 , BIKO             varchar           ( 2000 )                                      /* 140 備考         */
 , SEQNO            INTEGER                         DEFAULT 0   NOT NULL            /* 150 表示順       */
 , CDKH             varchar           (    1 )                                      /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);
